@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from curses import raw
+import json
 from requests import Response
 from syncari.models.request import (DescribeRequest, ErrorResponse,
     SyncRequest, WebhookRequest, RequestType, Request)
@@ -75,7 +75,13 @@ class Synapse(ABC):
             err.url = self.connection.endpoint
             response = ErrorResponse(message=err_msg, response=err)
 
-        return response
+        if (isinstance(response, list)):
+            json_vals = []
+            for v in response:
+                json_vals.append(v.json())
+            return json.dumps(json_vals)
+
+        return response.json()
         
     @property
     def name(self) -> str:
